@@ -2,7 +2,7 @@ package DBIx::Connector::Driver;
 
 use strict;
 use warnings;
-our $VERSION = '0.42';
+our $VERSION = '0.43';
 
 DRIVERS: {
     my %DRIVERS;
@@ -18,6 +18,11 @@ DRIVERS: {
     }
 }
 
+sub _connect {
+    my ($self, $dbh, $dsn, $username, $password, $attrs) = @_;
+    $dbh;
+}
+
 sub ping {
     my ($self, $dbh) = @_;
     $dbh->ping;
