@@ -3,7 +3,13 @@ package DBIx::Connector::Driver::mysql;
 use strict;
 use warnings;
 use base 'DBIx::Connector::Driver';
-our $VERSION = '0.42';
+our $VERSION = '0.43';
+
+sub _connect {
+    my $dbh = shift;
+    $dbh->{mysql_auto_reconnect} = 0;
+    $dbh;
+}
 
 sub savepoint {
     my ($self, $dbh, $name) = @_;
@@ -42,6 +48,18 @@ MySQL-specific implementations of the following methods:
 
 =back
 
+It also modifies the connection attributes as follows:
+
+=over
+
+=item C<mysql_auto_reconnect>
+
+Will always be set to false. This is to prevent MySQL's auto-reconnection
+feature from interfering with DBIx::Connector's auto-reconnection
+functionality in C<fixup> mode.
+
+=back
+
 =head1 Authors
 
 This module was written and is maintained by:
